@@ -11,7 +11,7 @@ use Readonly;
 use Net::LDAP;
 use base qw( Samba::LDAP::Base );
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.01';
 
 #
 # Add Log::Log4perl to all our classes!!!!
@@ -147,17 +147,22 @@ sub connect_ldap_master {
       )
       or die "LDAP Error: Can't contact master ldap server ($@)";
 
+    my $ldap_tls;
     if ( $self->{ldapTLS} == 1 ) {
-        $ldap_master->start_tls(
-            verify     => $self->{verify},
-            clientcert => $self->{clientcert},
-            clientkey  => $self->{clientkey},
-            cafile     => $self->{cafile},
+        $ldap_tls = $ldap_master->start_tls(
+                verify     => $self->{verify},
+                clientcert => $self->{clientcert},
+                clientkey  => $self->{clientkey},
+                cafile     => $self->{cafile},
         );
+        # Check TLS has started before binding
+        $ldap_tls->code && die "Failed to start TLS: ", $ldap_tls->error;
     }
-    $ldap_master->code && die "failed to start TLS: ", $ldap_master->error;
+    
+
+    my $result = $ldap_master->bind( $self->{masterDN}, password => $self->{masterPw}, );
+    $result->code && die("Bind error: ", $result->error, "\n");
 
-    $ldap_master->bind( $self->{masterDN}, password => $self->{masterPw}, );
     return $ldap_master;
 }
 
@@ -191,19 +196,25 @@ sub connect_ldap_slave {
           )
           or die "LDAP error: Can't contact master ldap server ($@)\n";
     }
+
     if ($ldap_slave) {
-        if ( $self->{ldapTLS} == 1 ) {
-            $ldap_slave->start_tls(
+    my $ldap_tls;
+    if ( $self->{ldapTLS} == 1 ) {
+        $ldap_tls = $ldap_slave->start_tls(
                 verify     => $self->{verify},
                 clientcert => $self->{clientcert},
                 clientkey  => $self->{clientkey},
                 cafile     => $self->{cafile},
-            );
-        }
-        $ldap_master->code && die "failed to start TLS: ", $ldap_master->error;
+        );
+        # Check TLS has started before binding
+        $ldap_tls->code && die "Failed to start TLS: ", $ldap_tls->error;
+    }
+    
 
-        $ldap_slave->bind( $self->{masterDN}, password => $self->{masterPw}, );
-        return $ldap_slave;
+    my $result = $ldap_slave->bind( $self->{slaveDN}, password => $self->{slavePw}, );
+    $result->code && die("Bind error: ", $result->error, "\n");
+
+    return $ldap_slave;
     }
 
     return;
@@ -250,7 +261,7 @@ Samba::LDAP - Manage a Samba PDC with an LDAP Backend
 
 =head1 VERSION
 
-This document describes Samba::LDAP version 0.02_01
+This document describes Samba::LDAP version 0.01
 
 
 =head1 SYNOPSIS
